##############################
config-decorator Documentation
##############################

.. |dob| replace:: ``dob``
.. _dob: https://github.com/hotoffthehamster/dob

.. |nark| replace:: ``nark``
.. _nark: https://github.com/hotoffthehamster/nark

User configuration framework developed for |nark|_ and |dob|_,
but potentially suitable for your next project!

.. toctree::
   :maxdepth: 4
   :caption: Package Documentation

   General Information <readme>
   Package Interface <modules>
   Software License <license>

.. Indices and tables
.. ==================
..
.. The general index, an A-Z list of API keywords, is not
.. super useful for this library, which is not very complicated.
..
..    * :ref:`genindex`
..
.. The module index is similar to the modules.rst TOC entry.
..
..    * :ref:`modindex`
..
.. There's a search in the left-hand sidebar, and in any case
.. following the link to the `search` page shows no results,
.. but also shows no search input control, so this is useless.
..
..   * :ref:`search`

